import QtQuick
import QtQuick.Window
import QtQuick3D
import QtQuick3D.Helpers 1.0
import QtQuick.Layouts

Window
{
    id: window
    width: 1920
    height: 1080
    visible: true
    title: qsTr("tk:dlg:programtitle")
    color: "black"

    Node
    {
        id: sceneRoot
        Node
        {
            id: sceneRootNode

            Node
            {
                Node
                {
                    id: reflectionScene

                    Component.onCompleted:
                    {
                        ModelController.setRootNode(this);
                    }

                    PerspectiveCamera
                    {
                        id: downCamera
                        position.z: 3.0
                        position.y: 3.0
                        eulerRotation: Qt.vector3d(-40, -10, 0)
                        clipNear: 1.0
                        clipFar: 10.0
                    }
                }
            }
        }

        PerspectiveCamera
        {
            id: mainCamera
            position.z: 3.0
            position.y: 3.0
            eulerRotation: Qt.vector3d(-40, -10, 0)
            clipNear: 1.0
            clipFar: 10.0
        }
    }

    Item
    {
        width: parent.width / 2
        height: parent.height

        View3D
        {
            anchors.fill: parent
            id: view
            camera: mainCamera
            importScene: sceneRoot
            environment: SceneEnvironment
            {
                clearColor: window.color
                antialiasingMode: SceneEnvironment.SSAA
                antialiasingQuality: SceneEnvironment.VeryHigh
                backgroundMode: SceneEnvironment.SkyBox
                lightProbe: Texture
                {
                    source: "qrc:/probes/day.hdr"
                    mappingMode: Texture.LightProbe
                }
                probeExposure: 1.5
            }
        }

    }
    Rectangle
    {
        width: 30
        height: 40
        color: "red"
        MouseArea
        {
            anchors.fill: parent
            onClicked:
            {
                ModelController.loadModel();
            }
        }
    }

    View3D
    {
        id: downView
        width: parent.width / 2
        height: parent.height
        anchors.right: parent.right
        importScene: reflectionScene
        camera: downCamera
        environment: SceneEnvironment
        {
            clearColor: "black"
            antialiasingMode: SceneEnvironment.MSAA
            antialiasingQuality: SceneEnvironment.VeryHigh
            backgroundMode: SceneEnvironment.SkyBox
            lightProbe: Texture {
                source: "qrc:/probes/day.hdr"
                mappingMode: Texture.LightProbe
            }
            probeExposure: 1.5
            tonemapMode: SceneEnvironment.TonemapModeLinear
        }
    }
}
